aboutsummaryrefslogtreecommitdiffstats
path: root/modules/calendar/e-cal-shell-view.c
diff options
context:
space:
mode:
Diffstat (limited to 'modules/calendar/e-cal-shell-view.c')
-rw-r--r--modules/calendar/e-cal-shell-view.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/modules/calendar/e-cal-shell-view.c b/modules/calendar/e-cal-shell-view.c
index 32f12b605f..41782deb7f 100644
--- a/modules/calendar/e-cal-shell-view.c
+++ b/modules/calendar/e-cal-shell-view.c
@@ -63,7 +63,7 @@ cal_shell_view_execute_search (EShellView *shell_view)
ECalendar *date_navigator;
GtkRadioAction *action;
GString *string;
- FilterRule *rule;
+ EFilterRule *rule;
const gchar *format;
const gchar *text;
time_t start_range;
@@ -179,10 +179,10 @@ cal_shell_view_execute_search (EShellView *shell_view)
}
}
/* XXX This is wrong. We need to programmatically construct a
* FilterRule, tell it to build code, and pass the resulting
* expressing string to ECalModel. */
- rule = filter_rule_new ();
+ rule = e_filter_rule_new ();
e_shell_content_set_search_rule (shell_content, rule);
g_object_unref (rule);
@@ -179,10 +179,10 @@ cal_shell_view_execute_search (EShellView *shell_view)
}
}
- /* XXX This is wrong. We need to programmatically construct a
- * FilterRule, tell it to build code, and pass the resulting
+ /* XXX This is wrong. We need to programmatically construct an
+ * EFilterRule, tell it to build code, and pass the resulting
* expressing string to ECalModel. */